==> nextcloud-11.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_sharing/l10n/fr.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "Partagés avec vous",
    "Shared with others" : "Partagés avec d'autres",
    "Shared by link" : "Partagés par lien",
    "Nothing shared with you yet" : "Aucun fichier n'est partagé avec vous pour l'instant",
    "Files and folders others share with you will show up here" : "Les fichiers et dossiers partagés avec vous apparaîtront ici",
    "Nothing shared yet" : "Rien n'est partagé pour l'instant",
    "Files and folders you share will show up here" : "Les fichiers et dossiers que vous partagez apparaîtront ici",
    "No shared links" : "Aucun partage par lien",
    "Files and folders you share by link will show up here" : "Les fichiers et dossiers que vous partagez par lien apparaîtront ici",
    "You can upload into this folder" : "Vous pouvez téléverser dans ce dossier",
    "No compatible server found at {remote}" : "Aucun serveur compatible trouvé sur {remote}",
    "Invalid server URL" : "URL serveur invalide",
    "Failed to add the public link to your Nextcloud" : "Echec de l'ajout du lien public à votre Nextcloud",
    "Share" : "Partager",
    "No expiration date set" : "Aucune date d'expiration définie",
    "Shared by" : "Partagé par",
    "Sharing" : "Partage",
    "File shares" : "Partages de fichiers",
    "Downloaded via public link" : "Téléchargé par lien public",
    "Downloaded by %1$s" : "Téléchargé par %1$s",
    "Downloaded by {email}" : "Téléchargé par {email}",
    "%1$s downloaded via public link" : "%1$s téléchargé par lien public",
    "{file} downloaded via public link" : "{file} téléchargé par lien public",
    "%1$s downloaded %2$s" : "%1$s a téléchargé %2$s",
    "{email} downloaded {file}" : "{email} a téléchargé {file}",
    "Shared with group %1$s" : "Partagé avec le groupe %1$s",
    "Shared with group {group}" : "Partagé avec le groupe {group}",
    "Removed share for group %1$s" : "Partage supprimé avec le groupe %1$s",
    "Removed share for group {group}" : "Partage supprimé avec le groupe {group}",
    "%2$s shared with group %1$s" : "%2$s a partagé avec le groupe %1$s",
    "{actor} shared with group {group}" : "{actor} a partagé avec le groupe {group}",
    "%2$s removed share for group %1$s" : "%2$s a supprimé le partage avec le groupe %1$s",
    "{actor} removed share for group {group}" : "{actor} a supprimé le partage avec le groupe {group}",
    "You shared %1$s with group %2$s" : "Vous avez partagé %1$s avec le groupe %2$s",
    "You shared {file} with group {group}" : "Vous avez partagé {file} avec le groupe {group}",
    "You removed group %2$s from %1$s" : "Vous avez supprimé le group %2$s de %1$s",
    "You removed group {group} from {file}" : "Vous avez supprimé le groupe {group} de {file}",
    "%3$s shared %1$s with group %2$s" : "%3$s a partagé %1$s avec le groupe %2$s",
    "{actor} shared {file} with group {group}" : "{actor} a partagé {file} avec le groupe {group}",
    "%3$s removed group %2$s from %1$s" : "%3$s a supprimé le groupe %2$s de %1$s",
    "{actor} removed group {group} from {file}" : "{actor} a supprimé le groupe {group} de {file}",
    "Shared as public link" : "Partagé avec un lien public",
    "Removed public link" : "Lien public supprimé",
    "%1$s shared as public link" : "%1$s a partagé avec un lien public",
    "{actor} shared as public link" : "{actor} a partagé avec un lien public",
    "%1$s removed public link" : "%1$s a supprimé le lien public",
    "{actor} removed public link" : "{actor} a supprimé le lien public",
    "You shared %1$s as public link" : "Vous avez partagé %1$s avec un lien public",
    "You shared {file} as public link" : "Vous avez partagé {file} avec un lien public",
    "You removed public link for %1$s" : "Vous avez supprimé le lien public pour %1$s",
    "You removed public link for {file}" : "Vous avez supprimé le lien public pour {file}",
    "%2$s shared %1$s as public link" : "%2$s a partagé %1$s avec un lien public",
    "{actor} shared {file} as public link" : "{actor} a partagé {file} avec un lien public",
    "%2$s removed public link for %1$s" : "%2$s a supprimé le lien public pour %1$s",
    "{actor} removed public link for {file}" : "{actor} a supprimé le lien public pour {file}",
    "%1$s accepted the remote share" : "%1$s a accepté le partage distant",
    "{user} accepted the remote share" : "{user} a accepté le partage distant",
    "%1$s declined the remote share" : "%1$s a refusé le partage distant",
    "{user} declined the remote share" : "{user} a refusé le partage distant",
    "You received a new remote share %1$s from %2$s" : "L'utilisateur %2$s a partagé la ressource distante %1$s avec vous",
    "You received a new remote share {file} from {user}" : "Vous avez reçu le partage distant {file} de {user}",
    "%2$s accepted the remote share of %1$s" : "%2$s a accepté le partage distant de %1$s",
    "{user} accepted the remote share of {file}" : "{user} a accepté le partage distant de {file}",
    "%2$s declined the remote share of %1$s" : "%2$s a refusé le partage distant de %1$s",
    "{user} declined the remote share of {file}" : "{user} a refusé le partage distant de {file}",
    "%2$s unshared %1$s from you" : "%2$s a cessé de partager %1$s avec vous",
    "{user} unshared {file} from you" : "{user} a cessé de partager {file} avec vous",
    "Shared with %1$s" : "Partagé avec %1$s",
    "Shared with {user}" : "Partagé avec {user}",
    "Removed share for %1$s" : "Partage supprimé pour %1$s",
    "Removed share for {user}" : "Partage supprimé pour {user}",
    "%2$s shared with %1$s" : "%2$s a partagé avec %1$s",
    "{actor} shared with {user}" : "{actor} a partagé avec {user}",
    "%2$s removed share for %1$s" : "%2$s a supprimé le partage pour %1$s",
    "{actor} removed share for {user}" : "{actor} a supprimé le partage pour {user}",
    "Shared by %1$s" : "Partagé par %1$s",
    "Shared by {actor}" : "Partagé par {actor}",
    "%1$s removed share" : "%1$s a supprimé le partage",
    "{actor} removed share" : "{actor} a supprimé le partage",
    "You shared %1$s with %2$s" : "Vous avez partagé %1$s avec %2$s",
    "You shared {file} with {user}" : "Vous avez partagé {file} avec {user}",
    "You removed %2$s from %1$s" : "Vous avez supprimé %2$s de %1$s",
    "You removed {user} from {file}" : "Vous avez supprimé {user} de {file}",
    "%3$s shared %1$s with %2$s" : "%3$s a partagé %1$s avec %2$s",
    "{actor} removed {user} from {file}" : "{actor} a supprimé {user} de {file}",
    "%3$s removed %2$s from %1$s" : "%3$s a supprimé %2$s de %1$s",
    "%2$s shared %1$s with you" : "%2$s a partagé %1$s avec vous",
    "{actor} shared {file} with you" : "{actor} a partagé {file} avec vous",
    "%2$s removed you from %1$s" : "%2$s vous a supprimé de %1$s",
    "{actor} removed you from {file}" : "{actor} vous a supprimé de {file}",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Un fichier ou un dossier partagé par mail ou par lien public a été <strong>téléchargé</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Un fichier ou un répertoire a été partagé depuis <strong>un autre serveur</strong>",
    "A file or folder has been <strong>shared</strong>" : "Un fichier ou un répertoire a été <strong>partagé</strong>",
    "Wrong share ID, share doesn't exist" : "Mauvais ID de partage, le partage n'existe pas",
    "could not delete share" : "impossible de supprimer le partage",
    "Could not delete share" : "Impossible de supprimer le partage",
    "Please specify a file or folder path" : "Veuillez spécifier un fichier ou dossier",
    "Wrong path, file/folder doesn't exist" : "Mauvais chemin, Le fichier/dossier n'existe pas",
    "Could not create share" : "Impossible de créer le partage",
    "invalid permissions" : "permissions invalides",
    "Please specify a valid user" : "Veuillez entrer un utilisateur valide",
    "Group sharing is disabled by the administrator" : "Le partage de groupe a été désactivé par l'administrateur",
    "Please specify a valid group" : "Veuillez entrer un groupe valide",
    "Public link sharing is disabled by the administrator" : "Le partage de lien public a été désactivé par l'administrateur",
    "Public upload disabled by the administrator" : "Téléversement public désactivé par l'administrateur",
    "Public upload is only possible for publicly shared folders" : "Le téléversement public est possible uniquement pour les dossiers partagés publiquement",
    "Invalid date, date format must be YYYY-MM-DD" : "Date invalide, le format doit être YYYY-MM-DD",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Le partage %s a échoué parce que l'infrastructure n'autorise pas les partages du type %s",
    "Unknown share type" : "Type de partage inconnu",
    "Not a directory" : "N'est pas un répertoire",
    "Could not lock path" : "Impossible de verrouiller le chemin",
    "Wrong or no update parameter given" : "Mauvais ou aucun paramètre donné ",
    "Can't change permissions for public share links" : "Impossible de changer les permissions pour les liens de partage public",
    "Cannot increase permissions" : "Impossible d'augmenter les permissions",
    "%s is publicly shared" : "%s a été partagé publiquement",
    "Share API is disabled" : "l'API de partage est désactivée",
    "This share is password-protected" : "Ce partage est protégé par un mot de passe",
    "The password is wrong. Try again." : "Le mot de passe est incorrect. Veuillez réessayer.",
    "Password" : "Mot de passe",
    "No entries found in this folder" : "Aucune entrée trouvée dans ce dossier",
    "Name" : "Nom",
    "Share time" : "Date de partage",
    "Expiration date" : "Date d'expiration",
    "Sorry, this link doesn’t seem to work anymore." : "Désolé, mais ce lien semble ne plus fonctionner.",
    "Reasons might be:" : "Les raisons peuvent être :",
    "the item was removed" : "l'élément a été supprimé",
    "the link expired" : "le lien a expiré",
    "sharing is disabled" : "le partage est désactivé",
    "For more info, please ask the person who sent this link." : "Pour plus d'informations, veuillez contacter la personne qui a envoyé ce lien.",
    "Add to your Nextcloud" : "Ajouter à votre Nextcloud",
    "Download" : "Télécharger",
    "Download %s" : "Télécharger %s",
    "Direct link" : "Lien direct",
    "Upload files to %s" : "Téléversement des fichiers vers %s",
    "Select or drop files" : "Sélectionner ou glisser-déposer vos fichiers",
    "Uploading files…" : "Téléversement des fichiers...",
    "Uploaded files:" : "Fichiers téléversés :",
    "A public shared file or folder was <strong>downloaded</strong>" : "Un fichier ou un répertoire partagé publiquement a été <strong>téléchargé</strong>",
    "You received a new remote share %2$s from %1$s" : "L'utilisateur %1$s a partagé la ressource distante %2$s avec vous",
    "You received a new remote share from %s" : "Vous avez reçu un partage distant de %s",
    "%1$s accepted remote share %2$s" : "%1$s a accepté le partage distant %2$s",
    "%1$s declined remote share %2$s" : "%1$s a refusé le partage distant %2$s",
    "%1$s unshared %2$s from you" : "%1$s a cessé de partager %2$s avec  vous",
    "Public shared folder %1$s was downloaded" : "Le dossier public %1$s a été téléchargé",
    "Public shared file %1$s was downloaded" : "Le fichier public %1$s a été téléchargé",
    "%2$s shared %1$s with %3$s" : "%2$s a partagé %1$s avec %3$s",
    "You removed the share of %2$s for %1$s" : "Vous avez supprimé le partage de %2$s pour %1$s",
    "%2$s removed the share of %3$s for %1$s" : "%2$s a supprimé votre partage de %3$s pour %1$s",
    "%2$s shared %1$s with group %3$s" : "%2$s partagé %1$s avec le groupe %3$s",
    "You removed the share of group %2$s for %1$s" : "Vous avez supprimé le partage du groupe %2$s pour %1$s",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s a supprimé le partage du groupe %3$s pour %1$s",
    "%2$s shared %1$s via link" : "%2$s a partagé %1$s par lien",
    "You shared %1$s via link" : "Vous avez partagé %1$s par lien public",
    "You removed the public link for %1$s" : "Vous avez supprimé le lien public pour %1$s",
    "%2$s removed the public link for %1$s" : "%2$s a supprimé le lien public pour %1$s",
    "Your public link for %1$s expired" : "Le lien public pour %1$s a expiré",
    "The public link of %2$s for %1$s expired" : "Le lien public de %2$s pour %1$s a expiré",
    "%2$s removed the share for %1$s" : "%2$s a supprimé le partage pour %1$s",
    "Shared with %2$s" : "Partagé avec %2$s",
    "Shared with %3$s by %2$s" : "Partagé avec %3$s par %2$s",
    "Removed share for %2$s" : "Partage supprimé pour %2$s",
    "%2$s removed share for %3$s" : "%2$s a supprimé le partage pour %3$s",
    "Shared with group %2$s" : "Partagé avec le groupe %2$s",
    "Shared with group %3$s by %2$s" : "Partagé avec le groupe %3$s par %2$s",
    "Removed share of group %2$s" : "Partage supprimé du groupe %2$s",
    "%2$s removed share of group %3$s" : "%2$s a supprimé le partage du groupe %3$s",
    "Shared via link by %2$s" : "Partagé via lien par %2$s",
    "Shared via public link" : "Partagé par lien public",
    "%2$s removed public link" : "%2$s a supprimé le lien public",
    "Public link expired" : "Lien public expiré",
    "Public link of %2$s expired" : "Le lien public de %2$s a expiré",
    "Shared by %2$s" : "Partagé par %2$s",
    "Shares" : "Partages"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_sharing/l10n/fr.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "Partagés avec vous",
    "Shared with others" : "Partagés avec d'autres",
    "Shared by link" : "Partagés par lien",
    "Nothing shared with you yet" : "Aucun fichier n'est partagé avec vous pour l'instant",
    "Files and folders others share with you will show up here" : "Les fichiers et dossiers partagés avec vous apparaîtront ici",
    "Nothing shared yet" : "Rien n'est partagé pour l'instant",
    "Files and folders you share will show up here" : "Les fichiers et dossiers que vous partagez apparaîtront ici",
    "No shared links" : "Aucun partage par lien",
    "Files and folders you share by link will show up here" : "Les fichiers et dossiers que vous partagez par lien apparaîtront ici",
    "You can upload into this folder" : "Vous pouvez téléverser dans ce dossier",
    "No compatible server found at {remote}" : "Aucun serveur compatible trouvé sur {remote}",
    "Invalid server URL" : "URL serveur invalide",
    "Failed to add the public link to your Nextcloud" : "Échec de l'ajout du lien public à votre Nextcloud",
    "Share" : "Partager",
    "No expiration date set" : "Aucune date d'expiration définie",
    "Shared by" : "Partagé par",
    "Sharing" : "Partage",
    "File shares" : "Partages de fichiers",
    "Downloaded via public link" : "Téléchargé par lien public",
    "Downloaded by {email}" : "Téléchargé par {email}",
    "{file} downloaded via public link" : "{file} téléchargé par lien public",
    "{email} downloaded {file}" : "{email} a téléchargé {file}",
    "Shared with group {group}" : "Partagé avec le groupe {group}",
    "Removed share for group {group}" : "Partage supprimé avec le groupe {group}",
    "{actor} shared with group {group}" : "{actor} a partagé avec le groupe {group}",
    "{actor} removed share for group {group}" : "{actor} a supprimé le partage avec le groupe {group}",
    "You shared {file} with group {group}" : "Vous avez partagé {file} avec le groupe {group}",
    "You removed group {group} from {file}" : "Vous avez supprimé le groupe {group} de {file}",
    "{actor} shared {file} with group {group}" : "{actor} a partagé {file} avec le groupe {group}",
    "{actor} removed group {group} from {file}" : "{actor} a supprimé le groupe {group} de {file}",
    "Shared as public link" : "Partagé avec un lien public",
    "Removed public link" : "Lien public supprimé",
    "Public link expired" : "Lien public expiré",
    "{actor} shared as public link" : "{actor} a partagé avec un lien public",
    "{actor} removed public link" : "{actor} a supprimé le lien public",
    "Public link of {actor} expired" : "Le lien public de {actor} a expiré",
    "You shared {file} as public link" : "Vous avez partagé {file} avec un lien public",
    "You removed public link for {file}" : "Vous avez supprimé le lien public pour {file}",
    "Public link expired for {file}" : "Le lien public a expiré pour {file}",
    "{actor} shared {file} as public link" : "{actor} a partagé {file} avec un lien public",
    "{actor} removed public link for {file}" : "{actor} a supprimé le lien public pour {file}",
    "Public link of {actor} for {file} expired" : "Le lien public de {actor} pour {file} a expiré",
    "{user} accepted the remote share" : "{user} a accepté le partage distant",
    "{user} declined the remote share" : "{user} a refusé le partage distant",
    "You received a new remote share {file} from {user}" : "Vous avez reçu le partage distant {file} de {user}",
    "{user} accepted the remote share of {file}" : "{user} a accepté le partage distant de {file}",
    "{user} declined the remote share of {file}" : "{user} a refusé le partage distant de {file}",
    "{user} unshared {file} from you" : "{user} a cessé de partager {file} avec vous",
    "Shared with {user}" : "Partagé avec {user}",
    "Removed share for {user}" : "Partage supprimé pour {user}",
    "{actor} shared with {user}" : "{actor} a partagé avec {user}",
    "{actor} removed share for {user}" : "{actor} a supprimé le partage pour {user}",
    "Shared by {actor}" : "Partagé par {actor}",
    "{actor} removed share" : "{actor} a supprimé le partage",
    "You shared {file} with {user}" : "Vous avez partagé {file} avec {user}",
    "You removed {user} from {file}" : "Vous avez supprimé {user} de {file}",
    "{actor} shared {file} with {user}" : "{actor} a partagé {file} avec {user}",
    "{actor} removed {user} from {file}" : "{actor} a supprimé {user} de {file}",
    "{actor} shared {file} with you" : "{actor} a partagé {file} avec vous",
    "{actor} removed you from {file}" : "{actor} vous a supprimé de {file}",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Un fichier ou un dossier partagé par mail ou par lien public a été <strong>téléchargé</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Un fichier ou un répertoire a été partagé depuis <strong>un autre serveur</strong>",
    "A file or folder has been <strong>shared</strong>" : "Un fichier ou un répertoire a été <strong>partagé</strong>",
    "Wrong share ID, share doesn't exist" : "Mauvais ID de partage, le partage n'existe pas",
    "could not delete share" : "impossible de supprimer le partage",
    "Could not delete share" : "Impossible de supprimer le partage",
    "Please specify a file or folder path" : "Veuillez indiquer un fichier ou un chemin",
    "Wrong path, file/folder doesn't exist" : "Mauvais chemin, Le fichier/dossier n'existe pas",
    "Could not create share" : "Impossible de créer le partage",
    "invalid permissions" : "permissions invalides",
    "Please specify a valid user" : "Veuillez entrer un utilisateur valide",
    "Group sharing is disabled by the administrator" : "Le partage de groupe a été désactivé par l'administrateur",
    "Please specify a valid group" : "Veuillez entrer un groupe valide",
    "Public link sharing is disabled by the administrator" : "Le partage de lien public a été désactivé par l'administrateur",
    "Public upload disabled by the administrator" : "Téléversement public désactivé par l'administrateur",
    "Public upload is only possible for publicly shared folders" : "Le téléversement public est possible uniquement pour les dossiers partagés publiquement",
    "Invalid date, date format must be YYYY-MM-DD" : "Date invalide, le format doit être YYYY-MM-DD",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Le partage %s a échoué parce que l'infrastructure n'autorise pas les partages du type %s",
    "You cannot share to a Circle if the app is not enabled" : "Vous ne pouvez pas partager au Cercle si l'application n'est pas activée",
    "Please specify a valid circle" : "Veuillez entrer un cercle valide",
    "Unknown share type" : "Type de partage inconnu",
    "Not a directory" : "N'est pas un répertoire",
    "Could not lock path" : "Impossible de verrouiller le chemin",
    "Wrong or no update parameter given" : "Mauvais ou aucun paramètre donné ",
    "Can't change permissions for public share links" : "Impossible de changer les permissions pour les liens de partage public",
    "Cannot increase permissions" : "Impossible d'augmenter les permissions",
    "%s is publicly shared" : "%s a été partagé publiquement",
    "Share API is disabled" : "l'API de partage est désactivée",
    "File sharing" : "Partage de fichiers",
    "This share is password-protected" : "Ce partage est protégé par un mot de passe",
    "The password is wrong. Try again." : "Le mot de passe est incorrect. Veuillez réessayer.",
    "Password" : "Mot de passe",
    "No entries found in this folder" : "Aucune entrée trouvée dans ce dossier",
    "Name" : "Nom",
    "Share time" : "Date de partage",
    "Expiration date" : "Date d'expiration",
    "Sorry, this link doesn’t seem to work anymore." : "Désolé, mais ce lien semble ne plus fonctionner.",
    "Reasons might be:" : "Les raisons peuvent être :",
    "the item was removed" : "l'élément a été supprimé",
    "the link expired" : "le lien a expiré",
    "sharing is disabled" : "le partage est désactivé",
    "For more info, please ask the person who sent this link." : "Pour plus d'informations, veuillez contacter la personne qui a envoyé ce lien.",
    "shared by %s" : "partagé par %s",
    "Add to your Nextcloud" : "Ajouter à votre Nextcloud",
    "Download" : "Télécharger",
    "Download %s" : "Télécharger %s",
    "Direct link" : "Lien direct",
    "Upload files to %s" : "Téléversement des fichiers vers %s",
    "Select or drop files" : "Sélectionner ou glisser-déposer vos fichiers",
    "Uploading files…" : "Téléversement des fichiers...",
    "Uploaded files:" : "Fichiers téléversés :"
},
"nplurals=2; plural=(n > 1);");
